*** Replication code for Pasricha, Falagiarda, Bijsterbosch and Aizenman (2015) - Section 5: Domestic effects of capital controls

set more off
 
clear all
cd "C:\"

use "C:\Dataset_DomesticEffects.dta", clear
tsset id quarterly

/// some data manupulation
	***Growth rates
	by id: gen dxr = (xr- l.xr)/l.xr
	foreach x in gin_saz gout_saz ginz goutz lx_sd NKIzgdp NKIsaz hgin_saz hgout_saz  MPA {
	by id: gen d`x' =d.`x'
	}

	
	** main openness variables
	gen open = -nettighteningin+neteasingout
	gen wopen = -wntighti +wneo
	gen whopen = whneo-whntighti

	** With absolute interest rate differential
	gen ar_diff1 = abs(str_diff1)
	by id: gen dar_diff1=d.ar_diff1
	by id: gen dstr_diff1=d.str_diff1
	
	** Chinn Ito and Schindler's opennes index
	by id: gen dka_CI =d.OD_ka_open
		** converting FKRSU to openness, renaming original to _r (restrictions)
		foreach x in  OD_ka OD_kai OD_kao {
		ren `x' `x'_r
		gen `x' = 1-`x'_r
		}
	foreach x in  OD_ka OD_kai OD_kao {
	by id: gen d`x' = d.`x'
	}
	
set autotabgraphs on 	
** Figure 4: Openness, D.abs ST interest rate differential, Gross Flows (SA), D.X Volatility. Exog: Lagged bank cr gr, Oil prices, US FF rate, USgdp_gr crisis 
pvar wopen dar_diff1 dgin_saz dgout_saz dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (wopen) save(Fig4, replace) name(Fig4, replace)

** Figure 5: Openness (Chinn-Ito index), D.abs ST interest rate differential, Gross Flows (SA), D.X Volatility. Exog: Lagged bank cr gr, Oil prices, US FF rate, USgdp_gr crisis 
pvar dka_CI dar_diff1 dgin_saz dgout_saz dlx_sd, exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (dka_CI) save(Fig5, replace) name(Fig5, replace)

** Figure 6: Openness (Fernandez et al. index), D.abs ST interest rate differential, Gross Flows (SA), D.X Volatility. Exog: Lagged bank cr gr, Oil prices, US FF rate, USgdp_gr crisis 
pvar dOD_ka dar_diff1 dgin_saz dgout_saz dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis ) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (dOD_ka) save(Fig6, replace) name(Fig6, replace)


////////////////////////////////////////////////////////////////////
//////////// For Table 1 and Figures 7-8: Instrumented NKI and exchange rate volatility
////////////////////////////////////////////////////////////////////
	
	** EME totals, without country i
	capture drop *_eme*
	foreach x in NKIsaz dxr   {
	gen `x'_eme =.
	forvalues i=1/16 {
	bysort quarterly: egen `x'_eme_`i' = sum(`x') if id~=`i'
	bysort quarterly (`x'_eme_`i'): replace `x'_eme_`i' = `x'_eme_`i'[_n-1] if _n>1
	tsset id quarterly
	replace `x'_eme = `x'_eme_`i' if id==`i'
	replace `x'_eme=. if `x'_eme==0 & quarterly==q(2001q1)
	drop `x'_eme_`i'
	}
	}
		** IV first stage regs
	tsset id quarterly
	capture drop *_hat
	foreach x in  NKIsaz dxr {
	xtreg `x' `x'_eme l.`x'_eme, fe
	predict `x'_hat if e(sample), xb
	}
	
	* Second stage regs to predict capital control changes
	**Table 1: 
	* wopen
	xtreg wopen   NKIsaz_hat dxr_hat , fe vce(cluster id)
	predict res_wopen, ue

	* wgt_nettighteningin
	xtreg wntighti  NKIsaz_hat dxr_hat , fe vce(cluster id)
	predict res_wntighti, ue

	* Third stage regs: panel vars

	** Figure 7: Openness (residual from first-stage regression), D.abs ST interest rate differential, Gross Flows (SA), D.X Volatility. Exog: Lagged bank cr gr, Oil prices, US FF rate, USgdp_gr crisis 
	pvar res_wopen dar_diff1 dgin_saz dgout_saz dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
	pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (res_wopen) save(Fig7, replace) name(Fig7, replace)


** Figure 8: Openness, D.abs ST interest rate differential, D.Reserves, Gross Flows (SA), D.X Volatility. Exog: Lagged bank cr gr, Oil prices, US FF rate, USgdp_gr crisis 
pvar wopen dar_diff1 DReserves_gdp dgin_saz dgout_saz dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (wopen) save(Fig8, replace) name(Fig8, replace)

** Figures 9 and 10: Net inflow tightening, Net ourflow easing, D.abs ST interest rate differential, Reserves, Gross Flows (SA), D.X Volatility. Exog: Lagged bank cr gr, Oil prices, US FF rate, USgdp_gr crisis 
pvar  wneo wntighti dar_diff1 dgin_saz dgout_saz dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (wntighti) save(Fig9, replace) name(Fig9, replace)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (wneo) save(Fig10, replace) name(Fig10, replace)



**************************************************
** Some robustness checks
**************************************************

set more off
set autotabgraphs on 

** with non-seasonally adjusted gross flows
pvar wopen dar_diff1  dginz dgoutz dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (wopen) name(RC1, replace) 


** Ordering change
pvar wopen  dgin_saz dgout_saz dar_diff1 dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (wopen) name(RC2a, replace) 

pvar wopen  dlx_sd  dgin_saz dgout_saz dar_diff1 , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (wopen) name(RC2b, replace)

** With nominal ST interest rate differential instead of its absolute value 
pvar wopen dstr_diff1 dgin_saz dgout_saz dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (wopen) save(RC3, replace) 


** Excluding FDI-related changes
pvar whopen dar_diff1 dhgin_saz dhgout_saz dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (whopen) name(RC4, replace) 

** With Aizenman-Chinn-Ito type index of monetary policy autonomy
pvar wopen dMPA dgin_saz dgout_saz dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(2)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (wopen) name(RC5, replace) 

** 3 lags instead of 2   
pvar wopen dar_diff1 dgin_saz dgout_saz dlx_sd , exog(l.MP2_dyBCPNFS  CrudeOilPrice us_ff_sr USgdp_gr crisis) lags(3)
pvarirf , step(15) oirf mc(100) level(90) byoption(rescale) impulse (wopen) name(RC6, replace) 


********************************************
*** Appendix Tables
*********************************************
** Table A2: Summary stats of global variables
tabstat USgdp_gr us_ff_sr CrudeOilPrice if wb_code=="IND", stat(mean sd max min)

** Table A3: Summary-stats of country-specific variables
tabstat dgin_saz dgout_saz dar_diff1, stat(mean sd max min) by(wb_code)

** Table A4: Summary-stats of country-specific variables
***converting to percentage points
replace dlx_sd = dlx_sd*100
replace dxr = dxr*100
tabstat dlx_sd dxr MP2_dyBCPNFS if wopen <. , stat(mean sd max min) by(wb_code)

